<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Descargador Básico</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Obtener Lista</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Ingresar URL:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Código de formato</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensión</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nombre del motor:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Pegar Contenido Portapapeles</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Usados Recientemente</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Establecer Opciones de Descarga</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Descarga por Lotes</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL a Descargar</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Pegar URL del portapapeles</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Supervisar portapapeles para URL</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Añadir Url a la Lista</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Establecer</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Descargador de listas de reproducción</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Opciones de descarga:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Hora de inicio del intervalo de tiempo(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Hora de finalización del intervalo de tiempo(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Capítulos (separados por comas):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividido por capítulos</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>URL de Lista de Reproducción:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Borrar archivo interno almacenando</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Usar archivo interno almacenando</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Referescar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir Carpeta</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Opciones Generales</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Mostrar icono de bandeja</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Guardar automáticamente la lista de medios sin descargar</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Ocultar automáticamente las descargas cuando se completen</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Restablecer Opción a su Valor Predeterminado</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Establecer Predeterminados</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opciones Predeterminadas</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Ruta para Descargas</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Seleccionar Idioma</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Utilice la configuración de proxy especificada manualmente</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Obtenga la configuración del proxy desde el entorno</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Sin Proxy</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Opciones predeterminadas del Motor</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obtener lista de opciones:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subscripciones</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Numbre IU</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Habilitar la pestaña Biblioteca</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Descargas simultáneas máximas</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codificacion de texto</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Sitio Web</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Nombre del Motor</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Opciones a añadir</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Gestor de URL</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opciones de Descarga</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Establecer que Url deberá ser gestionado por un motor en específico</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Filtro de Url</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Configuración de Proxy</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Configuración de proxy especificada manualmente
Ejemplo 1: 192.168.93.89:8080
Ejemplo 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 Opciones preestablecidas</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>El nombre de archivo con la extensión &quot;.txt&quot; solo guardará las direcciones URL</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Ocultar fila</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Mostrar todas las filas ocultas</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation type="unfinished">Copiar URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Guardar Lista en Archivo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Respoder a</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Guardar subtítulo en archivo</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nombre del motor:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Obtener Lista desde Archivo</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opciones Preestablecidas</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Abrir Carpeta de Descargas</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Derechos de Autor</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo electrónico</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Versón de Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Este programa es software libre; puede redistribuirlo y/o modificarlo según los términos de la Licencia Pública General de GNU publicada por la Free Software Foundation; ya sea la versión 2 de la Licencia o (a su elección) cualquier versión posterior.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Este programa se distribuye con la esperanza de que sea útil, pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la Licencia Pública General de GNU para obtener más detalles.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Polcaco (Polonia)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Inglés (EE.UU.)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Español</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Chino (China)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Turco (Turquía)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Ruso (Rusia)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Japonés (Japón)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Francés (Francia)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italiano (Italia)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Sueco (Suecia)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Alemán (Alemania)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portugués (Brasil)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Holandés (Países Bajos)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Error, no se pudo encontrar el ejecutable del backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Motor &quot;%1&quot; requiere al menos la versión &quot;%2&quot; de Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Para desactivar estas verificaciones, haga lo siguiente</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Vaya a la pestaña &quot;Configurar&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Vaya a la sub-pestaña &quot;Opciones Generales&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Ejecutando en modo portátil</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Ejecutando en modo de instalación</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Ruta de descarga: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Ruta de datos de la aplicación: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Configuración de la dirección del servidor proxy de %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Eliminar la dirección del servidor proxy</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Error, imposible analizar el archivo de configuración &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Falló al cargar un Complemento</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Fallo para encontrar el ejecutable &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>No se pudo encontrar el ejecutable de python3 para el backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Se produjo un error de red</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>La URL es incompatible</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Descarga cancelada</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Código de error</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Error de descarga, el motor falló al iniciar</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Error de descarga, el motor falló</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Código de formato</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensión</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>No se pudo abrir el archivo para escribir</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>No se pudo abrir el archivo para leerlo</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Tiempo transcurrido:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>No se pudo encontrar la información de la versión, asegúrese de que &quot;%1&quot; esté instalado y funcione correctamente</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Versión Encontrada</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Imposible abrir la ruta para escribir: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Imposible Extraer</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>La red falló en responder en %1 segundos</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Error al descargar, no se puede crear la siguiente ruta: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Iniciar Descarga</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Imposible encontrar el ejecutable &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Falló descarga</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Error al analizar el archivo json de github</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Actualización completa, reinicie para usar la nueva versión</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Archivo Inexistente</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Descarga completa</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Extrayendo archivo: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Procesando</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Descarga completada</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Restablecimiento de carpeta de descarga a predeterminada</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Post Procesamiento</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Forzar Descarga</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Mostrar Ventana de Registro</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Fecha de Subida:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Nombre del subtítulo</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opciones de Descarga</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Opciones de Descarga Extra</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Intervalo de tiempo de descarga</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Descargar Capítulos</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividido por capítulos</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Medio ya existe en archivo</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Tiempo restante</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Descargado</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 ya descargado</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Ésto Podría Demorar Mucho Tiempo</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Velocidad:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>La versión más reciente es %1, actualizando</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Verificando versión instalada de %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Se encontró la versión: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Actualice &quot;%1&quot; a al menos la versión &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>El formato solicitado no está disponible</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>URL introducida es inválida</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Mejor audio disponible únicamente</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Mejor audio disponible únicamente (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Mejor audio y vídeo disponibles</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Mejor audio con resolución de video de %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Advertencia: omitir el contenido del portapapeles</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Establecer Archivo de Lotes</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Descargando comentarios</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copiar URL</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Mostrar Subtítulos</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Mostrar Componentes</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Mostrar Opciones de Medio</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Descargar parte multimedios</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Establecer</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Descargando subtítulos</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Establecer como Predeterminado</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Seleccionar un Archivo de Motor</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Establecer Carpeta para Descargas</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Añadir</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">Establecer Predeterminados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Eliminar Todos</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Ventana de Registro</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Ocultar controles</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obtener lista de opciones:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copiar URL</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Mostrar Componentes</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Mostrar todo lo actualizado</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Descargar todo lo actualizado</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Gestionar Subscripciones</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Número de Páginas Descargadas</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Descargando información de video</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Mostrar Controles</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Ésto Podría Demorar Mucho Tiempo</translation>
    </message>
</context>
</TS>
